# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stellarstation/api/v1/stellarstation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from stellarstation.api.v1.orbit import orbit_pb2 as stellarstation_dot_api_dot_v1_dot_orbit_dot_orbit__pb2
from stellarstation.api.v1.radio import radio_pb2 as stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2
from stellarstation.api.v1 import transport_pb2 as stellarstation_dot_api_dot_v1_dot_transport__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='stellarstation/api/v1/stellarstation.proto',
  package='stellarstation.api.v1',
  syntax='proto3',
  serialized_options=b'\n\031com.stellarstation.api.v1B\023StellarstationProtoP\001Z2github.com/infostellarinc/go-stellarstation/api/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*stellarstation/api/v1/stellarstation.proto\x12\x15stellarstation.api.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\'stellarstation/api/v1/orbit/orbit.proto\x1a\'stellarstation/api/v1/radio/radio.proto\x1a%stellarstation/api/v1/transport.proto\"\xb8\x04\n\x16SatelliteStreamRequest\x12\x14\n\x0csatellite_id\x18\x01 \x01(\t\x12\x0f\n\x07plan_id\x18\x0b \x01(\t\x12\x19\n\x11ground_station_id\x18\x0c \x01(\t\x12\x11\n\tstream_id\x18\x02 \x01(\t\x12\x15\n\renable_events\x18\x05 \x01(\x08\x12\x12\n\nrequest_id\x18\x06 \x01(\t\x12^\n\x1fsend_satellite_commands_request\x18\x03 \x01(\x0b\x32\x33.stellarstation.api.v1.SendSatelliteCommandsRequestH\x00\x12h\n$ground_station_configuration_request\x18\x07 \x01(\x0b\x32\x38.stellarstation.api.v1.GroundStationConfigurationRequestH\x00\x12L\n\x16telemetry_received_ack\x18\t \x01(\x0b\x32*.stellarstation.api.v1.ReceiveTelemetryAckH\x00\x12\x38\n\x10\x61\x63\x63\x65pted_framing\x18\x04 \x03(\x0e\x32\x1e.stellarstation.api.v1.Framing\x12$\n\x1cresume_stream_message_ack_id\x18\x08 \x01(\t\x12\x1b\n\x13\x65nable_flow_control\x18\n \x01(\x08\x42\t\n\x07Request\"G\n\x1cSendSatelliteCommandsRequest\x12\x0f\n\x07\x63ommand\x18\x02 \x03(\x0c\x12\x16\n\x0e\x63hannel_set_id\x18\x03 \x01(\t\"\xe3\x01\n!GroundStationConfigurationRequest\x12\x61\n!transmitter_configuration_request\x18\x01 \x01(\x0b\x32\x36.stellarstation.api.v1.TransmitterConfigurationRequest\x12[\n\x1ereceiver_configuration_request\x18\x02 \x01(\x0b\x32\x33.stellarstation.api.v1.ReceiverConfigurationRequest\"e\n\x13ReceiveTelemetryAck\x12\x16\n\x0emessage_ack_id\x18\x01 \x01(\t\x12\x36\n\x12received_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xe8\x02\n\x1fTransmitterConfigurationRequest\x12\x32\n\x0e\x65nable_carrier\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x38\n\x14\x65nable_if_modulation\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x37\n\x13\x65nable_idle_pattern\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x33\n\x0f\x65nable_if_sweep\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12,\n\x07\x62itrate\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12;\n\nmodulation\x18\x06 \x01(\x0e\x32\'.stellarstation.api.v1.radio.Modulation\"\x89\x01\n\x1cReceiverConfigurationRequest\x12,\n\x07\x62itrate\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12;\n\nmodulation\x18\x02 \x01(\x0e\x32\'.stellarstation.api.v1.radio.Modulation\"\xcb\x01\n\x17SatelliteStreamResponse\x12\x11\n\tstream_id\x18\x01 \x01(\t\x12U\n\x1areceive_telemetry_response\x18\x02 \x01(\x0b\x32/.stellarstation.api.v1.ReceiveTelemetryResponseH\x00\x12:\n\x0cstream_event\x18\x03 \x01(\x0b\x32\".stellarstation.api.v1.StreamEventH\x00\x42\n\n\x08Response\"\xa9\x01\n\x18ReceiveTelemetryResponse\x12\x33\n\ttelemetry\x18\x01 \x03(\x0b\x32 .stellarstation.api.v1.Telemetry\x12\x0f\n\x07plan_id\x18\x02 \x01(\t\x12\x14\n\x0csatellite_id\x18\x04 \x01(\t\x12\x19\n\x11ground_station_id\x18\x05 \x01(\t\x12\x16\n\x0emessage_ack_id\x18\x03 \x01(\t\"$\n\x11\x43\x61ncelPlanRequest\x12\x0f\n\x07plan_id\x18\x01 \x01(\t\"\x14\n\x12\x43\x61ncelPlanResponse\":\n\"ListUpcomingAvailablePassesRequest\x12\x14\n\x0csatellite_id\x18\x01 \x01(\t\"P\n#ListUpcomingAvailablePassesResponse\x12)\n\x04pass\x18\x01 \x03(\x0b\x32\x1b.stellarstation.api.v1.Pass\"b\n\x12ReservePassRequest\x12\x19\n\x11reservation_token\x18\x01 \x01(\t\x12\x31\n\x08priority\x18\x02 \x01(\x0e\x32\x1f.stellarstation.api.v1.Priority\"@\n\x13ReservePassResponse\x12)\n\x04plan\x18\x01 \x01(\x0b\x32\x1b.stellarstation.api.v1.Plan\"\x87\x01\n\x10ListPlansRequest\x12\x14\n\x0csatellite_id\x18\x01 \x01(\t\x12-\n\taos_after\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\naos_before\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\">\n\x11ListPlansResponse\x12)\n\x04plan\x18\x01 \x03(\x0b\x32\x1b.stellarstation.api.v1.Plan\"\xb6\x01\n\nChannelSet\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x45\n\x06uplink\x18\x03 \x01(\x0b\x32\x35.stellarstation.api.v1.radio.RadioDeviceConfiguration\x12G\n\x08\x64ownlink\x18\x04 \x01(\x0b\x32\x35.stellarstation.api.v1.radio.RadioDeviceConfiguration\"\xa8\x04\n\x04Pass\x12,\n\x08\x61os_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08los_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1f\n\x17ground_station_latitude\x18\x04 \x01(\x01\x12 \n\x18ground_station_longitude\x18\x05 \x01(\x01\x12(\n ground_station_organization_name\x18\x0c \x01(\t\x12\x19\n\x11ground_station_id\x18\r \x01(\t\x12#\n\x1bground_station_country_code\x18\x06 \x01(\t\x12\x1d\n\x15max_elevation_degrees\x18\x07 \x01(\x01\x12\x36\n\x12max_elevation_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x46\n\x11\x63hannel_set_token\x18\x0b \x03(\x0b\x32+.stellarstation.api.v1.Pass.ChannelSetToken\x1ax\n\x0f\x43hannelSetToken\x12\x36\n\x0b\x63hannel_set\x18\x01 \x01(\x0b\x32!.stellarstation.api.v1.ChannelSet\x12\x19\n\x11reservation_token\x18\x02 \x01(\t\x12\x12\n\nunit_price\x18\x03 \x01(\x01\"\x99\x01\n\x11TelemetryMetadata\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x44\n\tdata_type\x18\x02 \x01(\x0e\x32\x31.stellarstation.api.v1.TelemetryMetadata.DataType\"1\n\x08\x44\x61taType\x12\x07\n\x03RAW\x10\x00\x12\x0f\n\x0b\x44\x45MODULATED\x10\x01\x12\x0b\n\x07\x44\x45\x43ODED\x10\x02\"\xe4\x06\n\x04Plan\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0csatellite_id\x18\x02 \x01(\t\x12#\n\x1bsatellite_organization_name\x18\x11 \x01(\t\x12\x32\n\x06status\x18\x03 \x01(\x0e\x32\".stellarstation.api.v1.Plan.Status\x12.\n\nstart_time\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x61os_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08los_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1f\n\x17ground_station_latitude\x18\x06 \x01(\x01\x12 \n\x18ground_station_longitude\x18\x07 \x01(\x01\x12#\n\x1bground_station_country_code\x18\x08 \x01(\t\x12(\n ground_station_organization_name\x18\x12 \x01(\t\x12\x19\n\x11ground_station_id\x18\x14 \x01(\t\x12\x1d\n\x15max_elevation_degrees\x18\t \x01(\x01\x12\x36\n\x12max_elevation_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x44\n\x12telemetry_metadata\x18\r \x03(\x0b\x32(.stellarstation.api.v1.TelemetryMetadata\x12\x36\n\x0b\x63hannel_set\x18\x10 \x01(\x0b\x32!.stellarstation.api.v1.ChannelSet\x12\x12\n\nunit_price\x18\x13 \x01(\x01\x12\x31\n\x08priority\x18\x15 \x01(\x0e\x32\x1f.stellarstation.api.v1.Priority\"^\n\x06Status\x12\x0c\n\x08RESERVED\x10\x00\x12\r\n\tEXECUTING\x10\x01\x12\r\n\tSUCCEEDED\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x12\x0c\n\x08\x43\x41NCELED\x10\x04\x12\x0e\n\nPROCESSING\x10\x05\"T\n\rAddTleRequest\x12\x14\n\x0csatellite_id\x18\x01 \x01(\t\x12-\n\x03tle\x18\x02 \x01(\x0b\x32 .stellarstation.api.v1.orbit.Tle\"\x10\n\x0e\x41\x64\x64TleResponse\"%\n\rGetTleRequest\x12\x14\n\x0csatellite_id\x18\x01 \x01(\t\"?\n\x0eGetTleResponse\x12-\n\x03tle\x18\x01 \x01(\x0b\x32 .stellarstation.api.v1.orbit.Tle\"\x9c\x01\n\x13SetTleSourceRequest\x12\x14\n\x0csatellite_id\x18\x01 \x01(\t\x12\x41\n\x06source\x18\x02 \x01(\x0e\x32\x31.stellarstation.api.v1.SetTleSourceRequest.Source\",\n\x06Source\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05NORAD\x10\x01\x12\n\n\x06MANUAL\x10\x02\"\x16\n\x14SetTleSourceResponse\"\xcc\x01\n\x0cPlanMetadata\x12\x43\n\x08metadata\x18\x02 \x03(\x0b\x32\x31.stellarstation.api.v1.PlanMetadata.MetadataEntry\x1a\x18\n\x08Metadata\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\t\x1a]\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12;\n\x05value\x18\x02 \x01(\x0b\x32,.stellarstation.api.v1.PlanMetadata.Metadata:\x02\x38\x01\"`\n\x16SetPlanMetadataRequest\x12\x0f\n\x07plan_id\x18\x01 \x01(\t\x12\x35\n\x08metadata\x18\x02 \x01(\x0b\x32#.stellarstation.api.v1.PlanMetadata\"\x19\n\x17SetPlanMetadataResponse*)\n\x08Priority\x12\x07\n\x03LOW\x10\x00\x12\n\n\x06MEDIUM\x10\x01\x12\x08\n\x04HIGH\x10\x02\x32\xda\x07\n\x15StellarStationService\x12^\n\tListPlans\x12\'.stellarstation.api.v1.ListPlansRequest\x1a(.stellarstation.api.v1.ListPlansResponse\x12\x61\n\nCancelPlan\x12(.stellarstation.api.v1.CancelPlanRequest\x1a).stellarstation.api.v1.CancelPlanResponse\x12\x94\x01\n\x1bListUpcomingAvailablePasses\x12\x39.stellarstation.api.v1.ListUpcomingAvailablePassesRequest\x1a:.stellarstation.api.v1.ListUpcomingAvailablePassesResponse\x12x\n\x13OpenSatelliteStream\x12-.stellarstation.api.v1.SatelliteStreamRequest\x1a..stellarstation.api.v1.SatelliteStreamResponse(\x01\x30\x01\x12\x64\n\x0bReservePass\x12).stellarstation.api.v1.ReservePassRequest\x1a*.stellarstation.api.v1.ReservePassResponse\x12U\n\x06\x41\x64\x64Tle\x12$.stellarstation.api.v1.AddTleRequest\x1a%.stellarstation.api.v1.AddTleResponse\x12U\n\x06GetTle\x12$.stellarstation.api.v1.GetTleRequest\x1a%.stellarstation.api.v1.GetTleResponse\x12g\n\x0cSetTleSource\x12*.stellarstation.api.v1.SetTleSourceRequest\x1a+.stellarstation.api.v1.SetTleSourceResponse\x12p\n\x0fSetPlanMetadata\x12-.stellarstation.api.v1.SetPlanMetadataRequest\x1a..stellarstation.api.v1.SetPlanMetadataResponseBf\n\x19\x63om.stellarstation.api.v1B\x13StellarstationProtoP\x01Z2github.com/infostellarinc/go-stellarstation/api/v1b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,stellarstation_dot_api_dot_v1_dot_orbit_dot_orbit__pb2.DESCRIPTOR,stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2.DESCRIPTOR,stellarstation_dot_api_dot_v1_dot_transport__pb2.DESCRIPTOR,])

_PRIORITY = _descriptor.EnumDescriptor(
  name='Priority',
  full_name='stellarstation.api.v1.Priority',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOW', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MEDIUM', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGH', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5173,
  serialized_end=5214,
)
_sym_db.RegisterEnumDescriptor(_PRIORITY)

Priority = enum_type_wrapper.EnumTypeWrapper(_PRIORITY)
LOW = 0
MEDIUM = 1
HIGH = 2


_TELEMETRYMETADATA_DATATYPE = _descriptor.EnumDescriptor(
  name='DataType',
  full_name='stellarstation.api.v1.TelemetryMetadata.DataType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RAW', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEMODULATED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DECODED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3528,
  serialized_end=3577,
)
_sym_db.RegisterEnumDescriptor(_TELEMETRYMETADATA_DATATYPE)

_PLAN_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='stellarstation.api.v1.Plan.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESERVED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXECUTING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUCCEEDED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CANCELED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROCESSING', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4354,
  serialized_end=4448,
)
_sym_db.RegisterEnumDescriptor(_PLAN_STATUS)

_SETTLESOURCEREQUEST_SOURCE = _descriptor.EnumDescriptor(
  name='Source',
  full_name='stellarstation.api.v1.SetTleSourceRequest.Source',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NORAD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4771,
  serialized_end=4815,
)
_sym_db.RegisterEnumDescriptor(_SETTLESOURCEREQUEST_SOURCE)


_SATELLITESTREAMREQUEST = _descriptor.Descriptor(
  name='SatelliteStreamRequest',
  full_name='stellarstation.api.v1.SatelliteStreamRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='satellite_id', full_name='stellarstation.api.v1.SatelliteStreamRequest.satellite_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plan_id', full_name='stellarstation.api.v1.SatelliteStreamRequest.plan_id', index=1,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ground_station_id', full_name='stellarstation.api.v1.SatelliteStreamRequest.ground_station_id', index=2,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='stellarstation.api.v1.SatelliteStreamRequest.stream_id', index=3,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_events', full_name='stellarstation.api.v1.SatelliteStreamRequest.enable_events', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='stellarstation.api.v1.SatelliteStreamRequest.request_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_satellite_commands_request', full_name='stellarstation.api.v1.SatelliteStreamRequest.send_satellite_commands_request', index=6,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ground_station_configuration_request', full_name='stellarstation.api.v1.SatelliteStreamRequest.ground_station_configuration_request', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='telemetry_received_ack', full_name='stellarstation.api.v1.SatelliteStreamRequest.telemetry_received_ack', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accepted_framing', full_name='stellarstation.api.v1.SatelliteStreamRequest.accepted_framing', index=9,
      number=4, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resume_stream_message_ack_id', full_name='stellarstation.api.v1.SatelliteStreamRequest.resume_stream_message_ack_id', index=10,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_flow_control', full_name='stellarstation.api.v1.SatelliteStreamRequest.enable_flow_control', index=11,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Request', full_name='stellarstation.api.v1.SatelliteStreamRequest.Request',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=256,
  serialized_end=824,
)


_SENDSATELLITECOMMANDSREQUEST = _descriptor.Descriptor(
  name='SendSatelliteCommandsRequest',
  full_name='stellarstation.api.v1.SendSatelliteCommandsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='stellarstation.api.v1.SendSatelliteCommandsRequest.command', index=0,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_set_id', full_name='stellarstation.api.v1.SendSatelliteCommandsRequest.channel_set_id', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=826,
  serialized_end=897,
)


_GROUNDSTATIONCONFIGURATIONREQUEST = _descriptor.Descriptor(
  name='GroundStationConfigurationRequest',
  full_name='stellarstation.api.v1.GroundStationConfigurationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transmitter_configuration_request', full_name='stellarstation.api.v1.GroundStationConfigurationRequest.transmitter_configuration_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receiver_configuration_request', full_name='stellarstation.api.v1.GroundStationConfigurationRequest.receiver_configuration_request', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=900,
  serialized_end=1127,
)


_RECEIVETELEMETRYACK = _descriptor.Descriptor(
  name='ReceiveTelemetryAck',
  full_name='stellarstation.api.v1.ReceiveTelemetryAck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_ack_id', full_name='stellarstation.api.v1.ReceiveTelemetryAck.message_ack_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='received_timestamp', full_name='stellarstation.api.v1.ReceiveTelemetryAck.received_timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1129,
  serialized_end=1230,
)


_TRANSMITTERCONFIGURATIONREQUEST = _descriptor.Descriptor(
  name='TransmitterConfigurationRequest',
  full_name='stellarstation.api.v1.TransmitterConfigurationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enable_carrier', full_name='stellarstation.api.v1.TransmitterConfigurationRequest.enable_carrier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_if_modulation', full_name='stellarstation.api.v1.TransmitterConfigurationRequest.enable_if_modulation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_idle_pattern', full_name='stellarstation.api.v1.TransmitterConfigurationRequest.enable_idle_pattern', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_if_sweep', full_name='stellarstation.api.v1.TransmitterConfigurationRequest.enable_if_sweep', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bitrate', full_name='stellarstation.api.v1.TransmitterConfigurationRequest.bitrate', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modulation', full_name='stellarstation.api.v1.TransmitterConfigurationRequest.modulation', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1233,
  serialized_end=1593,
)


_RECEIVERCONFIGURATIONREQUEST = _descriptor.Descriptor(
  name='ReceiverConfigurationRequest',
  full_name='stellarstation.api.v1.ReceiverConfigurationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bitrate', full_name='stellarstation.api.v1.ReceiverConfigurationRequest.bitrate', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modulation', full_name='stellarstation.api.v1.ReceiverConfigurationRequest.modulation', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1596,
  serialized_end=1733,
)


_SATELLITESTREAMRESPONSE = _descriptor.Descriptor(
  name='SatelliteStreamResponse',
  full_name='stellarstation.api.v1.SatelliteStreamResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='stellarstation.api.v1.SatelliteStreamResponse.stream_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receive_telemetry_response', full_name='stellarstation.api.v1.SatelliteStreamResponse.receive_telemetry_response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_event', full_name='stellarstation.api.v1.SatelliteStreamResponse.stream_event', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Response', full_name='stellarstation.api.v1.SatelliteStreamResponse.Response',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1736,
  serialized_end=1939,
)


_RECEIVETELEMETRYRESPONSE = _descriptor.Descriptor(
  name='ReceiveTelemetryResponse',
  full_name='stellarstation.api.v1.ReceiveTelemetryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='telemetry', full_name='stellarstation.api.v1.ReceiveTelemetryResponse.telemetry', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plan_id', full_name='stellarstation.api.v1.ReceiveTelemetryResponse.plan_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='satellite_id', full_name='stellarstation.api.v1.ReceiveTelemetryResponse.satellite_id', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ground_station_id', full_name='stellarstation.api.v1.ReceiveTelemetryResponse.ground_station_id', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_ack_id', full_name='stellarstation.api.v1.ReceiveTelemetryResponse.message_ack_id', index=4,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1942,
  serialized_end=2111,
)


_CANCELPLANREQUEST = _descriptor.Descriptor(
  name='CancelPlanRequest',
  full_name='stellarstation.api.v1.CancelPlanRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan_id', full_name='stellarstation.api.v1.CancelPlanRequest.plan_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2113,
  serialized_end=2149,
)


_CANCELPLANRESPONSE = _descriptor.Descriptor(
  name='CancelPlanResponse',
  full_name='stellarstation.api.v1.CancelPlanResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2151,
  serialized_end=2171,
)


_LISTUPCOMINGAVAILABLEPASSESREQUEST = _descriptor.Descriptor(
  name='ListUpcomingAvailablePassesRequest',
  full_name='stellarstation.api.v1.ListUpcomingAvailablePassesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='satellite_id', full_name='stellarstation.api.v1.ListUpcomingAvailablePassesRequest.satellite_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2173,
  serialized_end=2231,
)


_LISTUPCOMINGAVAILABLEPASSESRESPONSE = _descriptor.Descriptor(
  name='ListUpcomingAvailablePassesResponse',
  full_name='stellarstation.api.v1.ListUpcomingAvailablePassesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pass', full_name='stellarstation.api.v1.ListUpcomingAvailablePassesResponse.pass', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2233,
  serialized_end=2313,
)


_RESERVEPASSREQUEST = _descriptor.Descriptor(
  name='ReservePassRequest',
  full_name='stellarstation.api.v1.ReservePassRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reservation_token', full_name='stellarstation.api.v1.ReservePassRequest.reservation_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='stellarstation.api.v1.ReservePassRequest.priority', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2315,
  serialized_end=2413,
)


_RESERVEPASSRESPONSE = _descriptor.Descriptor(
  name='ReservePassResponse',
  full_name='stellarstation.api.v1.ReservePassResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan', full_name='stellarstation.api.v1.ReservePassResponse.plan', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2415,
  serialized_end=2479,
)


_LISTPLANSREQUEST = _descriptor.Descriptor(
  name='ListPlansRequest',
  full_name='stellarstation.api.v1.ListPlansRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='satellite_id', full_name='stellarstation.api.v1.ListPlansRequest.satellite_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aos_after', full_name='stellarstation.api.v1.ListPlansRequest.aos_after', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aos_before', full_name='stellarstation.api.v1.ListPlansRequest.aos_before', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2482,
  serialized_end=2617,
)


_LISTPLANSRESPONSE = _descriptor.Descriptor(
  name='ListPlansResponse',
  full_name='stellarstation.api.v1.ListPlansResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan', full_name='stellarstation.api.v1.ListPlansResponse.plan', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2619,
  serialized_end=2681,
)


_CHANNELSET = _descriptor.Descriptor(
  name='ChannelSet',
  full_name='stellarstation.api.v1.ChannelSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='stellarstation.api.v1.ChannelSet.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='stellarstation.api.v1.ChannelSet.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uplink', full_name='stellarstation.api.v1.ChannelSet.uplink', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='downlink', full_name='stellarstation.api.v1.ChannelSet.downlink', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2684,
  serialized_end=2866,
)


_PASS_CHANNELSETTOKEN = _descriptor.Descriptor(
  name='ChannelSetToken',
  full_name='stellarstation.api.v1.Pass.ChannelSetToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_set', full_name='stellarstation.api.v1.Pass.ChannelSetToken.channel_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reservation_token', full_name='stellarstation.api.v1.Pass.ChannelSetToken.reservation_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit_price', full_name='stellarstation.api.v1.Pass.ChannelSetToken.unit_price', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3301,
  serialized_end=3421,
)

_PASS = _descriptor.Descriptor(
  name='Pass',
  full_name='stellarstation.api.v1.Pass',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='aos_time', full_name='stellarstation.api.v1.Pass.aos_time', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='los_time', full_name='stellarstation.api.v1.Pass.los_time', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ground_station_latitude', full_name='stellarstation.api.v1.Pass.ground_station_latitude', index=2,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ground_station_longitude', full_name='stellarstation.api.v1.Pass.ground_station_longitude', index=3,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ground_station_organization_name', full_name='stellarstation.api.v1.Pass.ground_station_organization_name', index=4,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ground_station_id', full_name='stellarstation.api.v1.Pass.ground_station_id', index=5,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ground_station_country_code', full_name='stellarstation.api.v1.Pass.ground_station_country_code', index=6,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_elevation_degrees', full_name='stellarstation.api.v1.Pass.max_elevation_degrees', index=7,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_elevation_time', full_name='stellarstation.api.v1.Pass.max_elevation_time', index=8,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_set_token', full_name='stellarstation.api.v1.Pass.channel_set_token', index=9,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PASS_CHANNELSETTOKEN, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2869,
  serialized_end=3421,
)


_TELEMETRYMETADATA = _descriptor.Descriptor(
  name='TelemetryMetadata',
  full_name='stellarstation.api.v1.TelemetryMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='stellarstation.api.v1.TelemetryMetadata.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_type', full_name='stellarstation.api.v1.TelemetryMetadata.data_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TELEMETRYMETADATA_DATATYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3424,
  serialized_end=3577,
)


_PLAN = _descriptor.Descriptor(
  name='Plan',
  full_name='stellarstation.api.v1.Plan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='stellarstation.api.v1.Plan.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='satellite_id', full_name='stellarstation.api.v1.Plan.satellite_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='satellite_organization_name', full_name='stellarstation.api.v1.Plan.satellite_organization_name', index=2,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='stellarstation.api.v1.Plan.status', index=3,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='stellarstation.api.v1.Plan.start_time', index=4,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='stellarstation.api.v1.Plan.end_time', index=5,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aos_time', full_name='stellarstation.api.v1.Plan.aos_time', index=6,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='los_time', full_name='stellarstation.api.v1.Plan.los_time', index=7,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ground_station_latitude', full_name='stellarstation.api.v1.Plan.ground_station_latitude', index=8,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ground_station_longitude', full_name='stellarstation.api.v1.Plan.ground_station_longitude', index=9,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ground_station_country_code', full_name='stellarstation.api.v1.Plan.ground_station_country_code', index=10,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ground_station_organization_name', full_name='stellarstation.api.v1.Plan.ground_station_organization_name', index=11,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ground_station_id', full_name='stellarstation.api.v1.Plan.ground_station_id', index=12,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_elevation_degrees', full_name='stellarstation.api.v1.Plan.max_elevation_degrees', index=13,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_elevation_time', full_name='stellarstation.api.v1.Plan.max_elevation_time', index=14,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='telemetry_metadata', full_name='stellarstation.api.v1.Plan.telemetry_metadata', index=15,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_set', full_name='stellarstation.api.v1.Plan.channel_set', index=16,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit_price', full_name='stellarstation.api.v1.Plan.unit_price', index=17,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='stellarstation.api.v1.Plan.priority', index=18,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PLAN_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3580,
  serialized_end=4448,
)


_ADDTLEREQUEST = _descriptor.Descriptor(
  name='AddTleRequest',
  full_name='stellarstation.api.v1.AddTleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='satellite_id', full_name='stellarstation.api.v1.AddTleRequest.satellite_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tle', full_name='stellarstation.api.v1.AddTleRequest.tle', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4450,
  serialized_end=4534,
)


_ADDTLERESPONSE = _descriptor.Descriptor(
  name='AddTleResponse',
  full_name='stellarstation.api.v1.AddTleResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4536,
  serialized_end=4552,
)


_GETTLEREQUEST = _descriptor.Descriptor(
  name='GetTleRequest',
  full_name='stellarstation.api.v1.GetTleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='satellite_id', full_name='stellarstation.api.v1.GetTleRequest.satellite_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4554,
  serialized_end=4591,
)


_GETTLERESPONSE = _descriptor.Descriptor(
  name='GetTleResponse',
  full_name='stellarstation.api.v1.GetTleResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tle', full_name='stellarstation.api.v1.GetTleResponse.tle', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4593,
  serialized_end=4656,
)


_SETTLESOURCEREQUEST = _descriptor.Descriptor(
  name='SetTleSourceRequest',
  full_name='stellarstation.api.v1.SetTleSourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='satellite_id', full_name='stellarstation.api.v1.SetTleSourceRequest.satellite_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='stellarstation.api.v1.SetTleSourceRequest.source', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SETTLESOURCEREQUEST_SOURCE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4659,
  serialized_end=4815,
)


_SETTLESOURCERESPONSE = _descriptor.Descriptor(
  name='SetTleSourceResponse',
  full_name='stellarstation.api.v1.SetTleSourceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4817,
  serialized_end=4839,
)


_PLANMETADATA_METADATA = _descriptor.Descriptor(
  name='Metadata',
  full_name='stellarstation.api.v1.PlanMetadata.Metadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='stellarstation.api.v1.PlanMetadata.Metadata.data', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4927,
  serialized_end=4951,
)

_PLANMETADATA_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='stellarstation.api.v1.PlanMetadata.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='stellarstation.api.v1.PlanMetadata.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='stellarstation.api.v1.PlanMetadata.MetadataEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4953,
  serialized_end=5046,
)

_PLANMETADATA = _descriptor.Descriptor(
  name='PlanMetadata',
  full_name='stellarstation.api.v1.PlanMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='stellarstation.api.v1.PlanMetadata.metadata', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PLANMETADATA_METADATA, _PLANMETADATA_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4842,
  serialized_end=5046,
)


_SETPLANMETADATAREQUEST = _descriptor.Descriptor(
  name='SetPlanMetadataRequest',
  full_name='stellarstation.api.v1.SetPlanMetadataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan_id', full_name='stellarstation.api.v1.SetPlanMetadataRequest.plan_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='stellarstation.api.v1.SetPlanMetadataRequest.metadata', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5048,
  serialized_end=5144,
)


_SETPLANMETADATARESPONSE = _descriptor.Descriptor(
  name='SetPlanMetadataResponse',
  full_name='stellarstation.api.v1.SetPlanMetadataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5146,
  serialized_end=5171,
)

_SATELLITESTREAMREQUEST.fields_by_name['send_satellite_commands_request'].message_type = _SENDSATELLITECOMMANDSREQUEST
_SATELLITESTREAMREQUEST.fields_by_name['ground_station_configuration_request'].message_type = _GROUNDSTATIONCONFIGURATIONREQUEST
_SATELLITESTREAMREQUEST.fields_by_name['telemetry_received_ack'].message_type = _RECEIVETELEMETRYACK
_SATELLITESTREAMREQUEST.fields_by_name['accepted_framing'].enum_type = stellarstation_dot_api_dot_v1_dot_transport__pb2._FRAMING
_SATELLITESTREAMREQUEST.oneofs_by_name['Request'].fields.append(
  _SATELLITESTREAMREQUEST.fields_by_name['send_satellite_commands_request'])
_SATELLITESTREAMREQUEST.fields_by_name['send_satellite_commands_request'].containing_oneof = _SATELLITESTREAMREQUEST.oneofs_by_name['Request']
_SATELLITESTREAMREQUEST.oneofs_by_name['Request'].fields.append(
  _SATELLITESTREAMREQUEST.fields_by_name['ground_station_configuration_request'])
_SATELLITESTREAMREQUEST.fields_by_name['ground_station_configuration_request'].containing_oneof = _SATELLITESTREAMREQUEST.oneofs_by_name['Request']
_SATELLITESTREAMREQUEST.oneofs_by_name['Request'].fields.append(
  _SATELLITESTREAMREQUEST.fields_by_name['telemetry_received_ack'])
_SATELLITESTREAMREQUEST.fields_by_name['telemetry_received_ack'].containing_oneof = _SATELLITESTREAMREQUEST.oneofs_by_name['Request']
_GROUNDSTATIONCONFIGURATIONREQUEST.fields_by_name['transmitter_configuration_request'].message_type = _TRANSMITTERCONFIGURATIONREQUEST
_GROUNDSTATIONCONFIGURATIONREQUEST.fields_by_name['receiver_configuration_request'].message_type = _RECEIVERCONFIGURATIONREQUEST
_RECEIVETELEMETRYACK.fields_by_name['received_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TRANSMITTERCONFIGURATIONREQUEST.fields_by_name['enable_carrier'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_TRANSMITTERCONFIGURATIONREQUEST.fields_by_name['enable_if_modulation'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_TRANSMITTERCONFIGURATIONREQUEST.fields_by_name['enable_idle_pattern'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_TRANSMITTERCONFIGURATIONREQUEST.fields_by_name['enable_if_sweep'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_TRANSMITTERCONFIGURATIONREQUEST.fields_by_name['bitrate'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_TRANSMITTERCONFIGURATIONREQUEST.fields_by_name['modulation'].enum_type = stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2._MODULATION
_RECEIVERCONFIGURATIONREQUEST.fields_by_name['bitrate'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_RECEIVERCONFIGURATIONREQUEST.fields_by_name['modulation'].enum_type = stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2._MODULATION
_SATELLITESTREAMRESPONSE.fields_by_name['receive_telemetry_response'].message_type = _RECEIVETELEMETRYRESPONSE
_SATELLITESTREAMRESPONSE.fields_by_name['stream_event'].message_type = stellarstation_dot_api_dot_v1_dot_transport__pb2._STREAMEVENT
_SATELLITESTREAMRESPONSE.oneofs_by_name['Response'].fields.append(
  _SATELLITESTREAMRESPONSE.fields_by_name['receive_telemetry_response'])
_SATELLITESTREAMRESPONSE.fields_by_name['receive_telemetry_response'].containing_oneof = _SATELLITESTREAMRESPONSE.oneofs_by_name['Response']
_SATELLITESTREAMRESPONSE.oneofs_by_name['Response'].fields.append(
  _SATELLITESTREAMRESPONSE.fields_by_name['stream_event'])
_SATELLITESTREAMRESPONSE.fields_by_name['stream_event'].containing_oneof = _SATELLITESTREAMRESPONSE.oneofs_by_name['Response']
_RECEIVETELEMETRYRESPONSE.fields_by_name['telemetry'].message_type = stellarstation_dot_api_dot_v1_dot_transport__pb2._TELEMETRY
_LISTUPCOMINGAVAILABLEPASSESRESPONSE.fields_by_name['pass'].message_type = _PASS
_RESERVEPASSREQUEST.fields_by_name['priority'].enum_type = _PRIORITY
_RESERVEPASSRESPONSE.fields_by_name['plan'].message_type = _PLAN
_LISTPLANSREQUEST.fields_by_name['aos_after'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPLANSREQUEST.fields_by_name['aos_before'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPLANSRESPONSE.fields_by_name['plan'].message_type = _PLAN
_CHANNELSET.fields_by_name['uplink'].message_type = stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2._RADIODEVICECONFIGURATION
_CHANNELSET.fields_by_name['downlink'].message_type = stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2._RADIODEVICECONFIGURATION
_PASS_CHANNELSETTOKEN.fields_by_name['channel_set'].message_type = _CHANNELSET
_PASS_CHANNELSETTOKEN.containing_type = _PASS
_PASS.fields_by_name['aos_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PASS.fields_by_name['los_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PASS.fields_by_name['max_elevation_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PASS.fields_by_name['channel_set_token'].message_type = _PASS_CHANNELSETTOKEN
_TELEMETRYMETADATA.fields_by_name['data_type'].enum_type = _TELEMETRYMETADATA_DATATYPE
_TELEMETRYMETADATA_DATATYPE.containing_type = _TELEMETRYMETADATA
_PLAN.fields_by_name['status'].enum_type = _PLAN_STATUS
_PLAN.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN.fields_by_name['aos_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN.fields_by_name['los_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN.fields_by_name['max_elevation_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN.fields_by_name['telemetry_metadata'].message_type = _TELEMETRYMETADATA
_PLAN.fields_by_name['channel_set'].message_type = _CHANNELSET
_PLAN.fields_by_name['priority'].enum_type = _PRIORITY
_PLAN_STATUS.containing_type = _PLAN
_ADDTLEREQUEST.fields_by_name['tle'].message_type = stellarstation_dot_api_dot_v1_dot_orbit_dot_orbit__pb2._TLE
_GETTLERESPONSE.fields_by_name['tle'].message_type = stellarstation_dot_api_dot_v1_dot_orbit_dot_orbit__pb2._TLE
_SETTLESOURCEREQUEST.fields_by_name['source'].enum_type = _SETTLESOURCEREQUEST_SOURCE
_SETTLESOURCEREQUEST_SOURCE.containing_type = _SETTLESOURCEREQUEST
_PLANMETADATA_METADATA.containing_type = _PLANMETADATA
_PLANMETADATA_METADATAENTRY.fields_by_name['value'].message_type = _PLANMETADATA_METADATA
_PLANMETADATA_METADATAENTRY.containing_type = _PLANMETADATA
_PLANMETADATA.fields_by_name['metadata'].message_type = _PLANMETADATA_METADATAENTRY
_SETPLANMETADATAREQUEST.fields_by_name['metadata'].message_type = _PLANMETADATA
DESCRIPTOR.message_types_by_name['SatelliteStreamRequest'] = _SATELLITESTREAMREQUEST
DESCRIPTOR.message_types_by_name['SendSatelliteCommandsRequest'] = _SENDSATELLITECOMMANDSREQUEST
DESCRIPTOR.message_types_by_name['GroundStationConfigurationRequest'] = _GROUNDSTATIONCONFIGURATIONREQUEST
DESCRIPTOR.message_types_by_name['ReceiveTelemetryAck'] = _RECEIVETELEMETRYACK
DESCRIPTOR.message_types_by_name['TransmitterConfigurationRequest'] = _TRANSMITTERCONFIGURATIONREQUEST
DESCRIPTOR.message_types_by_name['ReceiverConfigurationRequest'] = _RECEIVERCONFIGURATIONREQUEST
DESCRIPTOR.message_types_by_name['SatelliteStreamResponse'] = _SATELLITESTREAMRESPONSE
DESCRIPTOR.message_types_by_name['ReceiveTelemetryResponse'] = _RECEIVETELEMETRYRESPONSE
DESCRIPTOR.message_types_by_name['CancelPlanRequest'] = _CANCELPLANREQUEST
DESCRIPTOR.message_types_by_name['CancelPlanResponse'] = _CANCELPLANRESPONSE
DESCRIPTOR.message_types_by_name['ListUpcomingAvailablePassesRequest'] = _LISTUPCOMINGAVAILABLEPASSESREQUEST
DESCRIPTOR.message_types_by_name['ListUpcomingAvailablePassesResponse'] = _LISTUPCOMINGAVAILABLEPASSESRESPONSE
DESCRIPTOR.message_types_by_name['ReservePassRequest'] = _RESERVEPASSREQUEST
DESCRIPTOR.message_types_by_name['ReservePassResponse'] = _RESERVEPASSRESPONSE
DESCRIPTOR.message_types_by_name['ListPlansRequest'] = _LISTPLANSREQUEST
DESCRIPTOR.message_types_by_name['ListPlansResponse'] = _LISTPLANSRESPONSE
DESCRIPTOR.message_types_by_name['ChannelSet'] = _CHANNELSET
DESCRIPTOR.message_types_by_name['Pass'] = _PASS
DESCRIPTOR.message_types_by_name['TelemetryMetadata'] = _TELEMETRYMETADATA
DESCRIPTOR.message_types_by_name['Plan'] = _PLAN
DESCRIPTOR.message_types_by_name['AddTleRequest'] = _ADDTLEREQUEST
DESCRIPTOR.message_types_by_name['AddTleResponse'] = _ADDTLERESPONSE
DESCRIPTOR.message_types_by_name['GetTleRequest'] = _GETTLEREQUEST
DESCRIPTOR.message_types_by_name['GetTleResponse'] = _GETTLERESPONSE
DESCRIPTOR.message_types_by_name['SetTleSourceRequest'] = _SETTLESOURCEREQUEST
DESCRIPTOR.message_types_by_name['SetTleSourceResponse'] = _SETTLESOURCERESPONSE
DESCRIPTOR.message_types_by_name['PlanMetadata'] = _PLANMETADATA
DESCRIPTOR.message_types_by_name['SetPlanMetadataRequest'] = _SETPLANMETADATAREQUEST
DESCRIPTOR.message_types_by_name['SetPlanMetadataResponse'] = _SETPLANMETADATARESPONSE
DESCRIPTOR.enum_types_by_name['Priority'] = _PRIORITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SatelliteStreamRequest = _reflection.GeneratedProtocolMessageType('SatelliteStreamRequest', (_message.Message,), {
  'DESCRIPTOR' : _SATELLITESTREAMREQUEST,
  '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.SatelliteStreamRequest)
  })
_sym_db.RegisterMessage(SatelliteStreamRequest)

SendSatelliteCommandsRequest = _reflection.GeneratedProtocolMessageType('SendSatelliteCommandsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENDSATELLITECOMMANDSREQUEST,
  '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.SendSatelliteCommandsRequest)
  })
_sym_db.RegisterMessage(SendSatelliteCommandsRequest)

GroundStationConfigurationRequest = _reflection.GeneratedProtocolMessageType('GroundStationConfigurationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GROUNDSTATIONCONFIGURATIONREQUEST,
  '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.GroundStationConfigurationRequest)
  })
_sym_db.RegisterMessage(GroundStationConfigurationRequest)

ReceiveTelemetryAck = _reflection.GeneratedProtocolMessageType('ReceiveTelemetryAck', (_message.Message,), {
  'DESCRIPTOR' : _RECEIVETELEMETRYACK,
  '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.ReceiveTelemetryAck)
  })
_sym_db.RegisterMessage(ReceiveTelemetryAck)

TransmitterConfigurationRequest = _reflection.GeneratedProtocolMessageType('TransmitterConfigurationRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRANSMITTERCONFIGURATIONREQUEST,
  '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.TransmitterConfigurationRequest)
  })
_sym_db.RegisterMessage(TransmitterConfigurationRequest)

ReceiverConfigurationRequest = _reflection.GeneratedProtocolMessageType('ReceiverConfigurationRequest', (_message.Message,), {
  'DESCRIPTOR' : _RECEIVERCONFIGURATIONREQUEST,
  '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.ReceiverConfigurationRequest)
  })
_sym_db.RegisterMessage(ReceiverConfigurationRequest)

SatelliteStreamResponse = _reflection.GeneratedProtocolMessageType('SatelliteStreamResponse', (_message.Message,), {
  'DESCRIPTOR' : _SATELLITESTREAMRESPONSE,
  '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.SatelliteStreamResponse)
  })
_sym_db.RegisterMessage(SatelliteStreamResponse)

ReceiveTelemetryResponse = _reflection.GeneratedProtocolMessageType('ReceiveTelemetryResponse', (_message.Message,), {
  'DESCRIPTOR' : _RECEIVETELEMETRYRESPONSE,
  '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.ReceiveTelemetryResponse)
  })
_sym_db.RegisterMessage(ReceiveTelemetryResponse)

CancelPlanRequest = _reflection.GeneratedProtocolMessageType('CancelPlanRequest', (_message.Message,), {
  'DESCRIPTOR' : _CANCELPLANREQUEST,
  '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.CancelPlanRequest)
  })
_sym_db.RegisterMessage(CancelPlanRequest)

CancelPlanResponse = _reflection.GeneratedProtocolMessageType('CancelPlanResponse', (_message.Message,), {
  'DESCRIPTOR' : _CANCELPLANRESPONSE,
  '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.CancelPlanResponse)
  })
_sym_db.RegisterMessage(CancelPlanResponse)

ListUpcomingAvailablePassesRequest = _reflection.GeneratedProtocolMessageType('ListUpcomingAvailablePassesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTUPCOMINGAVAILABLEPASSESREQUEST,
  '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.ListUpcomingAvailablePassesRequest)
  })
_sym_db.RegisterMessage(ListUpcomingAvailablePassesRequest)

ListUpcomingAvailablePassesResponse = _reflection.GeneratedProtocolMessageType('ListUpcomingAvailablePassesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTUPCOMINGAVAILABLEPASSESRESPONSE,
  '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.ListUpcomingAvailablePassesResponse)
  })
_sym_db.RegisterMessage(ListUpcomingAvailablePassesResponse)

ReservePassRequest = _reflection.GeneratedProtocolMessageType('ReservePassRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESERVEPASSREQUEST,
  '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.ReservePassRequest)
  })
_sym_db.RegisterMessage(ReservePassRequest)

ReservePassResponse = _reflection.GeneratedProtocolMessageType('ReservePassResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESERVEPASSRESPONSE,
  '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.ReservePassResponse)
  })
_sym_db.RegisterMessage(ReservePassResponse)

ListPlansRequest = _reflection.GeneratedProtocolMessageType('ListPlansRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPLANSREQUEST,
  '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.ListPlansRequest)
  })
_sym_db.RegisterMessage(ListPlansRequest)

ListPlansResponse = _reflection.GeneratedProtocolMessageType('ListPlansResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPLANSRESPONSE,
  '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.ListPlansResponse)
  })
_sym_db.RegisterMessage(ListPlansResponse)

ChannelSet = _reflection.GeneratedProtocolMessageType('ChannelSet', (_message.Message,), {
  'DESCRIPTOR' : _CHANNELSET,
  '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.ChannelSet)
  })
_sym_db.RegisterMessage(ChannelSet)

Pass = _reflection.GeneratedProtocolMessageType('Pass', (_message.Message,), {

  'ChannelSetToken' : _reflection.GeneratedProtocolMessageType('ChannelSetToken', (_message.Message,), {
    'DESCRIPTOR' : _PASS_CHANNELSETTOKEN,
    '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
    # @@protoc_insertion_point(class_scope:stellarstation.api.v1.Pass.ChannelSetToken)
    })
  ,
  'DESCRIPTOR' : _PASS,
  '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.Pass)
  })
_sym_db.RegisterMessage(Pass)
_sym_db.RegisterMessage(Pass.ChannelSetToken)

TelemetryMetadata = _reflection.GeneratedProtocolMessageType('TelemetryMetadata', (_message.Message,), {
  'DESCRIPTOR' : _TELEMETRYMETADATA,
  '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.TelemetryMetadata)
  })
_sym_db.RegisterMessage(TelemetryMetadata)

Plan = _reflection.GeneratedProtocolMessageType('Plan', (_message.Message,), {
  'DESCRIPTOR' : _PLAN,
  '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.Plan)
  })
_sym_db.RegisterMessage(Plan)

AddTleRequest = _reflection.GeneratedProtocolMessageType('AddTleRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDTLEREQUEST,
  '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.AddTleRequest)
  })
_sym_db.RegisterMessage(AddTleRequest)

AddTleResponse = _reflection.GeneratedProtocolMessageType('AddTleResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDTLERESPONSE,
  '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.AddTleResponse)
  })
_sym_db.RegisterMessage(AddTleResponse)

GetTleRequest = _reflection.GeneratedProtocolMessageType('GetTleRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTLEREQUEST,
  '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.GetTleRequest)
  })
_sym_db.RegisterMessage(GetTleRequest)

GetTleResponse = _reflection.GeneratedProtocolMessageType('GetTleResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTLERESPONSE,
  '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.GetTleResponse)
  })
_sym_db.RegisterMessage(GetTleResponse)

SetTleSourceRequest = _reflection.GeneratedProtocolMessageType('SetTleSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETTLESOURCEREQUEST,
  '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.SetTleSourceRequest)
  })
_sym_db.RegisterMessage(SetTleSourceRequest)

SetTleSourceResponse = _reflection.GeneratedProtocolMessageType('SetTleSourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETTLESOURCERESPONSE,
  '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.SetTleSourceResponse)
  })
_sym_db.RegisterMessage(SetTleSourceResponse)

PlanMetadata = _reflection.GeneratedProtocolMessageType('PlanMetadata', (_message.Message,), {

  'Metadata' : _reflection.GeneratedProtocolMessageType('Metadata', (_message.Message,), {
    'DESCRIPTOR' : _PLANMETADATA_METADATA,
    '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
    # @@protoc_insertion_point(class_scope:stellarstation.api.v1.PlanMetadata.Metadata)
    })
  ,

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _PLANMETADATA_METADATAENTRY,
    '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
    # @@protoc_insertion_point(class_scope:stellarstation.api.v1.PlanMetadata.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _PLANMETADATA,
  '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.PlanMetadata)
  })
_sym_db.RegisterMessage(PlanMetadata)
_sym_db.RegisterMessage(PlanMetadata.Metadata)
_sym_db.RegisterMessage(PlanMetadata.MetadataEntry)

SetPlanMetadataRequest = _reflection.GeneratedProtocolMessageType('SetPlanMetadataRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETPLANMETADATAREQUEST,
  '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.SetPlanMetadataRequest)
  })
_sym_db.RegisterMessage(SetPlanMetadataRequest)

SetPlanMetadataResponse = _reflection.GeneratedProtocolMessageType('SetPlanMetadataResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETPLANMETADATARESPONSE,
  '__module__' : 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.SetPlanMetadataResponse)
  })
_sym_db.RegisterMessage(SetPlanMetadataResponse)


DESCRIPTOR._options = None
_PLANMETADATA_METADATAENTRY._options = None

_STELLARSTATIONSERVICE = _descriptor.ServiceDescriptor(
  name='StellarStationService',
  full_name='stellarstation.api.v1.StellarStationService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=5217,
  serialized_end=6203,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListPlans',
    full_name='stellarstation.api.v1.StellarStationService.ListPlans',
    index=0,
    containing_service=None,
    input_type=_LISTPLANSREQUEST,
    output_type=_LISTPLANSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CancelPlan',
    full_name='stellarstation.api.v1.StellarStationService.CancelPlan',
    index=1,
    containing_service=None,
    input_type=_CANCELPLANREQUEST,
    output_type=_CANCELPLANRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListUpcomingAvailablePasses',
    full_name='stellarstation.api.v1.StellarStationService.ListUpcomingAvailablePasses',
    index=2,
    containing_service=None,
    input_type=_LISTUPCOMINGAVAILABLEPASSESREQUEST,
    output_type=_LISTUPCOMINGAVAILABLEPASSESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OpenSatelliteStream',
    full_name='stellarstation.api.v1.StellarStationService.OpenSatelliteStream',
    index=3,
    containing_service=None,
    input_type=_SATELLITESTREAMREQUEST,
    output_type=_SATELLITESTREAMRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReservePass',
    full_name='stellarstation.api.v1.StellarStationService.ReservePass',
    index=4,
    containing_service=None,
    input_type=_RESERVEPASSREQUEST,
    output_type=_RESERVEPASSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddTle',
    full_name='stellarstation.api.v1.StellarStationService.AddTle',
    index=5,
    containing_service=None,
    input_type=_ADDTLEREQUEST,
    output_type=_ADDTLERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTle',
    full_name='stellarstation.api.v1.StellarStationService.GetTle',
    index=6,
    containing_service=None,
    input_type=_GETTLEREQUEST,
    output_type=_GETTLERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetTleSource',
    full_name='stellarstation.api.v1.StellarStationService.SetTleSource',
    index=7,
    containing_service=None,
    input_type=_SETTLESOURCEREQUEST,
    output_type=_SETTLESOURCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetPlanMetadata',
    full_name='stellarstation.api.v1.StellarStationService.SetPlanMetadata',
    index=8,
    containing_service=None,
    input_type=_SETPLANMETADATAREQUEST,
    output_type=_SETPLANMETADATARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_STELLARSTATIONSERVICE)

DESCRIPTOR.services_by_name['StellarStationService'] = _STELLARSTATIONSERVICE

# @@protoc_insertion_point(module_scope)



# Copyright 2018 Infostellar, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import os
import setuptools

with open('README.md', 'r') as fh:
    long_description = fh.read()

setuptools.setup(
    name='stellarstation',
    version='0.15.0',
    author='StellarStation API Team',
    author_email='stellarstation-api-team@istellar.jp',
    description='Client stubs for accessing the StellarStation API',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/infostellarinc/stellarstation-api',
    packages=setuptools.find_packages(),
    classifiers=(
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent ',
    ),
    install_requires=(
        'grpcio',
        'protobuf',
    ),
)
